translate.convert.odf2xliff

Package translate :: Package convert :: Module odf2xliff |
[hide private]
[frames] | no frames]

# Module odf2xliff

source code

convert OpenDocument (ODF) files to XLIFF localization files

Functions | [hide private]
convertodf(inputfile, outputfile, templates, engine=`'``toolkit``'`) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Variables | [hide private]
| formats = ``{``'``odc``'``:` `(``'``xlf``'``,` <function convertodf at 0x428a9b0>`)``,``...``
| __package__ = ``'``translate.convert``'``

Imports: factory, contextmanager, with_, odf_io

Variables Details | [hide private]

  ### formats Value:
      {"sxw":("xlf", convertodf), "odt":("xlf", convertodf), "ods":("xlf", c
      onvertodf), "odp":("xlf", convertodf), "odg":("xlf", convertodf), "odc
      ":("xlf", convertodf), "odf":("xlf", convertodf), "odi":("xlf", conver
      todf), "odm":("xlf", convertodf), "ott":("xlf", convertodf), "ots":("x
      lf", convertodf), "otp":("xlf", convertodf), "otg":("xlf", convertodf)
      , "otc":("xlf", convertodf), "otf":("xlf", convertodf), "oti":("xlf",
      convertodf), "oth":("xlf", convertodf),}